@@ -1,8 +1,8 @@
 """Worklab data processing package"""
 
-__version__ = "1.4.6"
+__version__ = "1.5.0"
 
-__all__ = ['com', 'kin', 'move', 'physio', 'utils', 'plots']
+__all__ = ['com', 'kin', 'move', 'physio', 'utils', 'plots', 'imu']
 
 from . import com
 from . import kin
@@ -10,3 +10,4 @@ from . import move
 from . import physio
 from . import utils
 from . import plots
+from . import imu
