@@ -200,6 +200,7 @@ def lowpass_butter(array, sfreq=100., cutoff=20., order=2):
 
     """
     # noinspection PyTupleAssignmentBalance
+    array = np.array(array)
     sos = butter(order//2, cutoff, fs=sfreq, btype='low', output='sos')
     return sosfiltfilt(sos, array)
 
@@ -516,6 +517,8 @@ def find_nearest(array, value, index=False):
 
     Returns
     -------
+    np.array
+        value or index of nearest value
 
     """
     array = np.asarray(array)
@@ -523,6 +526,29 @@ def find_nearest(array, value, index=False):
     return idx if index else array[idx]
 
 
+def split_dataframe(df, inds):
+    """
+    Split a dataframe on a list of indices. For example a dataframe that contains multiple sessions of wheelchair
+    ergometer data.
+
+    Parameters
+    ----------
+    df : pd.DataFrame
+        target dataframe
+    inds : list
+        list of indices where the dataframe should be split
+
+    Returns
+    -------
+    list
+        list of dataframes
+
+    """
+    df.reset_index(drop=True, inplace=True)
+    inds = [0] + list(inds) + [len(df)]  # add first and last index for slicing
+    return [df.iloc[start:stop, :].copy().reset_index(drop=True) for start, stop in zip(inds[0::], inds[1::])]
+
+
 def binned_stats(array, bins=10, pad=True, func=np.mean, nan_func=np.nanmean):
     """
     Apply a compatible Numpy function to every bins samples (e.g. mean or std).
